@@ -4,7 +4,7 @@ from enum import Enum
 from typing import Optional, List
 from uuid import UUID
 
-from shuttlis.geography import Location
+from shuttl_geo import Location
 from shuttlis.serialization import serialize
 
 
